<?php
/*
 Note: I don't really like to have a utils file but this is a first
 step to refactoring the many different functions that are being
 used in this plugin.
*/

/**
 * Description: Database setup for the rsvp plug-in.
 */
function rsvp_pro_database_setup() {
	global $wpdb;
	rsvp_pro_update_database( $wpdb );
}

/**
 * Gets option information for a given event. It can handle multiple events.
 *
 * @param  int    $event_id    The event we are trying to get the information for.
 * @param  string $option_name The option name we want the information for.
 * @return mixed               The value from the option we are looking for.
 */
function rsvp_pro_get_event_option( $event_id, $option_name ) {
	global $wpdb;
	global $rsvp_options;

	$value   = '';
	$options = null;

	if ( isset( $rsvp_options[ $event_id ] ) && is_array( $rsvp_options[ $event_id ] ) ) {
		$options = $rsvp_options[ $event_id ];
	} elseif ( strcasecmp( $wpdb->get_var( 'SHOW TABLES LIKE \'' . PRO_EVENT_TABLE . '\'' ), PRO_EVENT_TABLE ) === 0 ) {
		$options = $wpdb->get_var( $wpdb->prepare( 'SELECT options FROM ' . PRO_EVENT_TABLE . ' WHERE id = %d', $event_id ) );
		if ( ! empty( $options ) ) {
			$options = json_decode( $options, true );
		}
		$rsvp_options[ $event_id ] = $options;
	}

	if ( is_array( $options ) && isset( $options[ $option_name ] ) ) {
		if ( is_array( $options[ $option_name ] ) ) {
			$value = $options[ $option_name ];
		} else {
			$value = stripslashes( $options[ $option_name ] );
			$key   = rsvp_pro_get_event_name( $event_id ) . ' - ' . $option_name;
			$value = rsvp_pro_get_dynamic_translated_string( $key, $value, $event_id );
		}
	}

	return $value;
}

function rsvp_pro_get_sub_event_option( $subEventId, $option_name ) {
	global $wpdb;
	global $rsvp_sub_options;
	$value = '';

	if (isset($rsvp_sub_options[$subEventId]) && is_array($rsvp_sub_options[$subEventId])) {
		$options = $rsvp_sub_options[$subEventId];
	} else {
		$options = $wpdb->get_var($wpdb->prepare("SELECT options FROM ".PRO_EVENT_TABLE." WHERE id = %d", $subEventId));
		if (!empty($options)) {
			$options = json_decode($options, true);
		}
		$rsvp_sub_options[$subEventId] = $options;
	}
	if (is_array($options) && isset($options[$option_name])) {
		if (is_array($options[$option_name])) {
			$value = $options[$option_name];
		} else {
			$value = stripslashes( $options[$option_name] );
			$key   = rsvp_pro_get_event_name( $subEventId ) . ' - ' . $option_name;
			$value = rsvp_pro_get_dynamic_translated_string( $key, $value, $subEventId );
		}
	}
	return $value;
}

function rsvp_pro_get_event_information($eventId, $informationKey)
{
    global $wpdb;
    global $event_information;

    if( $event_information === null ) {
        $event_information = array();
    }

    if ((count($event_information) <= 0) || ($event_information[RSVP_PRO_INFO_EVENT_ID] != $eventId)) {
        $info = $wpdb->get_row( $wpdb->prepare("SELECT id, eventName, open_date, close_date, event_access,
                                                 eventStartDate, eventEndDate, eventLocation, eventDescription, 
                                                 open_date_time, open_date_timezone, close_date_time, close_date_timezone, 
                                                 attendee_list_sent_on, attendee_columns
                                                 FROM ".PRO_EVENT_TABLE." WHERE id = %d", $eventId));
        if( $info )
        {
            $event_information[RSVP_PRO_INFO_EVENT_NAME] = stripslashes($info->eventName);
            $event_information[RSVP_PRO_INFO_OPEN_DATE] = date("m/d/Y", strtotime($info->open_date));
            $event_information[RSVP_PRO_INFO_CLOSE_DATE] = date("m/d/Y", strtotime($info->close_date));
            $event_information[RSVP_PRO_INFO_EVENT_ID] = $info->id;
            $event_information[RSVP_PRO_INFO_EVENT_ACCESS] = $info->event_access;
            $event_information[RSVP_PRO_INFO_EVENT_START_DATE] = date("m/d/Y", strtotime($info->eventStartDate));
            $event_information[RSVP_PRO_INFO_EVENT_END_DATE] = date("m/d/Y", strtotime($info->eventEndDate));
            $event_information[RSVP_PRO_INFO_LOCATION] =  rsvp_pro_get_dynamic_translated_string( rsvp_pro_get_event_name( $eventId ) . ' - ' . rsvp_pro_get_frontend_string( 'event_location_label' ), stripslashes($info->eventLocation), $eventId );
            $event_information[RSVP_PRO_INFO_DESCRIPTION] = rsvp_pro_get_dynamic_translated_string( rsvp_pro_get_event_name( $eventId ) . ' - ' . rsvp_pro_get_admin_string( 'settings_event_description_label' ), stripslashes($info->eventDescription), $eventId );
            $event_information[RSVP_PRO_INFO_OPEN_DATE_TIME] = stripslashes($info->open_date_time);
            $event_information[RSVP_PRO_INFO_OPEN_DATE_TIMEZONE] = stripslashes($info->open_date_timezone);
            $event_information[RSVP_PRO_INFO_CLOSE_DATE_TIME] = stripslashes($info->close_date_time);
            $event_information[RSVP_PRO_INFO_CLOSE_DATE_TIMEZONE] = stripslashes($info->close_date_timezone);
            $event_information[RSVP_PRO_INFO_ATTENDEE_LIST_COLUMNS] = array_filter( explode(',', stripslashes( $info->attendee_columns ) ) );
        }
    }

    return $event_information[$informationKey];
}

function rsvp_pro_require_passcode($rsvpId)
{
    if ((rsvp_pro_get_event_option($rsvpId, RSVP_PRO_OPTION_OPEN_REGISTRATION) == "Y") && (rsvp_pro_get_event_option($rsvpId, RSVP_PRO_OPTION_RSVP_OPEN_NO_PASSCODE) == "Y")) {
        return false;
    }

    if (rsvp_pro_get_event_option($rsvpId, RSVP_PRO_OPTION_PASSCODE) == "Y") {
        return true;
    }

    if (rsvp_pro_get_event_option($rsvpId, RSVP_PRO_OPTION_OPEN_REGISTRATION) == "Y") {
        return true;
    }

    if (rsvp_pro_get_event_option($rsvpId, RSVP_PRO_ONLY_PASSCODE) == "Y") {
        return true;
    }

    return false;
}

function rsvp_pro_require_only_passcode_to_register($rsvpId)
{
    return (rsvp_pro_get_event_option($rsvpId, RSVP_PRO_ONLY_PASSCODE) == "Y");
}

function rsvp_pro_require_unique_passcode($rsvpId)
{
    return rsvp_pro_require_only_passcode_to_register($rsvpId);
}

function rsvp_pro_waitlist_enabled($rsvpId)
{
    if (rsvp_pro_get_event_option($rsvpId, RSVP_PRO_OPTION_ENABLE_WAITLIST) == "Y") {
        return true;
    }

    return false;
}

/**
 * This generates a random 6 character passcode to be used for guests when the option is enabled.
 */
function rsvp_pro_generate_passcode($length = 6)
{
    $characters = '0123456789abcdefghijklmnopqrstuvwxyz';
    $passcode = "";

    for ($p = 0; $p < $length; $p++) {
        $passcode .= $characters[ mt_rand( 0, ( strlen($characters) - 1 ) ) ];
    }

    return $passcode;
}

function rsvp_pro_is_free_rsvp_installed()
{
    global $wpdb;

    $table = $wpdb->prefix."attendees";
    return ($wpdb->get_var("SHOW TABLES LIKE '$table'") == $table);
}

function rsvp_pro_update_db_check()
{
    global $wpdb;
    if (get_option("rsvp_pro_db_version") != RSVP_PRO_DB_VERSION) {
        require_once("rsvp-db-setup.inc.php");
        rsvp_pro_update_database($wpdb);
    }
}

function rsvp_pro_getCurrentPageURL()
{
    global $rsvp_id;
    global $wp;
    global $wp_rewrite;

    $page_url = home_url( $wp->request );

    if( $wp_rewrite->using_index_permalinks() && ( strpos( $page_url, "index.php" ) === false ) ) {
        $parts = parse_url( $page_url );

        $page_url = $parts['scheme'] . '://' . $parts['host'];

        if( isset( $parts['port'] ) ) {
            $page_url .= ':' . $parts['port'];
        }

        $page_url .= '/index.php'. $parts['path'];

        if( isset( $parts['query'] ) && ( $parts['query'] != '' ) ) {
            $page_url .= '?' . $parts['query'];
        }
    } elseif( empty( $wp_rewrite->permalink_structure ) ) {        
        $page_url = get_permalink();
    }

    if (rsvp_pro_get_event_option($rsvp_id, RSVP_PRO_OPTION_DONT_USE_HASH) != "Y") {
        $page_url .= "#rsvpArea";
    }
    return $page_url;
}

function rsvp_pro_humanize_rsvp_status($rsvpStatus, $event_id = 0)
{
    if (strtolower($rsvpStatus) == "noresponse") {
        $text = rsvp_pro_get_frontend_string('noresponse_text');
        if (($event_id > 0) && (rsvp_pro_get_event_option($event_id, RSVP_PRO_OPTION_NO_RESPONSE_TEXT) !== '')) {
            $text = rsvp_pro_get_event_option($event_id, RSVP_PRO_OPTION_NO_RESPONSE_TEXT);
        }

        return $text;
    } elseif (strtolower($rsvpStatus) == "yes") {
        $text = rsvp_pro_get_frontend_string('yes_text');

        if (($event_id > 0) && (rsvp_pro_get_event_option($event_id, RSVP_PRO_OPTION_YES_TEXT) !== '')) {
            $text = rsvp_pro_get_event_option($event_id, RSVP_PRO_OPTION_YES_TEXT);
        }

        return $text;
    } elseif (strtolower($rsvpStatus) == "no") {
        $text = rsvp_pro_get_frontend_string('no_text');

        if (($event_id > 0) && (rsvp_pro_get_event_option($event_id, RSVP_PRO_OPTION_NO_TEXT) !== '')) {
            $text = rsvp_pro_get_event_option($event_id, RSVP_PRO_OPTION_NO_TEXT);
        }

        return $text;
    } elseif (strtolower($rsvpStatus) == "waitlist") {
        $text = rsvp_pro_get_frontend_string('waitlist_text');

        if (($event_id > 0) && (rsvp_pro_get_event_option($event_id, RSVP_PRO_OPTION_WAITLIST_TEXT) !== '')) {
            $text = rsvp_pro_get_event_option($event_id, RSVP_PRO_OPTION_WAITLIST_TEXT);
        }

        return $text;
    } elseif (strtolower($rsvpStatus) === 'maybe') {
        $text = rsvp_pro_get_frontend_string('maybe_text');

        if (($event_id > 0) && (rsvp_pro_get_event_option($event_id, RSVP_PRO_OPTION_MAYBE_TEXT) !== '')) {
            $text = rsvp_pro_get_event_option($event_id, RSVP_PRO_OPTION_MAYBE_TEXT);
        }

        return $text;
    } elseif( strtolower($rsvpStatus) === 'plusone') {
        $text = rsvp_pro_get_frontend_string('plusone_text');

        if (($event_id > 0) && (rsvp_pro_get_event_option($event_id, RSVP_PRO_OPTION_YES_PLUS_ONE_TEXT) !== '')) {
            $text = rsvp_pro_get_event_option($event_id, RSVP_PRO_OPTION_YES_PLUS_ONE_TEXT);
        }

        return $text;
    }

    return $rsvpStatus;
}

/**
 * Takes the RSVP status and translates it from the database stored
 * value to what the web forms are expecting
 *
 * @param  string $rsvp_status The RSVP status stored in the database
 * @return string              The RSVP status that is expected on the web form
 */
function rsvp_pro_translate_status_to_form_value($rsvp_status)
{
    $tmp_status = strToUpper($rsvp_status);
    if ( $tmp_status === "YES") {
        return "Y";
    } elseif ($tmp_status === "WAITLIST") {
        return "W";
    } elseif ($tmp_status === "MAYBE") {
        return"M";
    } elseif ($tmp_status === 'NORESPONSE') {
        return "NoResponse";
    } elseif ($tmp_status === 'PLUSONE') {
        return 'P';
    } else {
        return "N";
    }
}

/**
 * Takes the form value for the RSVP status and translates it to the
 * expected value for the database.
 *
 * @param  string $form_value The form value that was submitted by the user
 * @return string             The corresponding RSVP database value
 */
function rsvp_pro_translate_form_value_to_status( $form_value ) {
	$tmp_value = strtoupper( $form_value );

	if ( $tmp_value == 'Y' ) {
		return 'Yes';
	} elseif ( $tmp_value == 'W' ) {
		return 'Waitlist';
	} elseif ( $tmp_value == 'M' ) {
		return 'Maybe';
	} elseif ( $tmp_value == 'NORESPONSE' ) {
		return 'NoResponse';
	} elseif ( $tmp_value === 'PLUSONE' ) {
		return 'PlusOne';
	} else {
		return 'No';
	}
}

function rsvp_pro_get_event_status($rsvpStatus, $eventId, $isSubEvent)
{
    $function = "rsvp_pro_get_event_option";

    if ($isSubEvent) {
        $function = "rsvp_pro_get_sub_event_option";
    }

    if (strtolower($rsvpStatus) == "yes") {
        $tmp = $function($eventId, RSVP_PRO_OPTION_YES_VERBIAGE);
        if (empty($tmp)) {
            $tmp = rsvp_pro_humanize_rsvp_status($rsvpStatus);
        }

        return $tmp;
    } elseif (strtolower($rsvpStatus) == "no") {
        $tmp = $function($eventId, RSVP_PRO_OPTION_NO_VERBIAGE);
        if (empty($tmp)) {
            $tmp = rsvp_pro_humanize_rsvp_status($rsvpStatus);
        }

        return $tmp;
    } elseif (strtolower($rsvpStatus) == "maybe") {
        $tmp = $function($eventId, RSVP_PRO_OPTION_MAYBE_VERBIAGE);
        if (empty($tmp)) {
            $tmp = rsvp_pro_humanize_rsvp_status($rsvpStatus);
        }

        return $tmp;
    } elseif (strtolower($rsvpStatus) === 'plusone') {
        $tmp = $function($eventId, RSVP_PRO_OPTION_PLUS_ONE_LABEL);

        if (empty($tmp)) {
            $tmp = rsvp_pro_humanize_rsvp_status($rsvpStatus);
        }

        return $tmp;
    }

    return rsvp_pro_humanize_rsvp_status($rsvpStatus);
}

/**
 * Formats the RSVP status so it matches up with how the enums have the
 * RSVP status. This is used because in certain database setups the enums
 * are case sensitive which can cause statuses not to be saved.
 *
 * @param  string $status The current RSVP status
 * @return string         A correctly formatted RSVP status for the database
 */
function rsvp_pro_format_rsvp_status_for_database( $status )
{
    $formatted_status = $status;
    $tmp_status = strtolower( $status );

    if ( $tmp_status == 'noresponse' ) {
        $tmp_status = 'NoResponse';
    } elseif ( $tmp_status == 'yes' ) {
        $tmp_status = 'Yes';
    } elseif ( $tmp_status == 'no' ) {
        $tmp_status = 'No';
    } elseif ( $tmp_status === 'waitlist' ) {
        $tmp_status = 'Waitlist';
    } elseif ( $tmp_status === 'maybe' ) {
        $tmp_status = 'Maybe';
    } elseif ( $tmp_status === 'plusone' ) {
        $tmp_status = 'PlusOne';
    }

    return $tmp_status;
}

function rsvp_pro_get_salutation_options($rsvpId)
{
    $salutations = rsvp_pro_get_event_option($rsvpId, RSVP_PRO_OPTION_SALUTATIONS);
    if (empty($salutations)) {
        $salutations = RSVP_PRO_DEFAULT_SALUTATION;
    }
    $salutations = explode("||", $salutations);

    return $salutations;
}

function rsvp_pro_is_sub_or_parent_event($rsvpId)
{
    global $wpdb;

    $sql = "SELECT COUNT(*) FROM ".PRO_EVENT_TABLE." WHERE parentEventID = %d OR (id = %d AND parentEventID > 0)";
    $count = $wpdb->get_var($wpdb->prepare($sql, $rsvpId, $rsvpId));
    if ($count > 0) {
        return true;
    } else {
        return false;
    }
}

function rsvp_pro_is_sub_event($rsvpId)
{
    global $wpdb;

    $sql = "SELECT COUNT(*) FROM ".PRO_EVENT_TABLE." WHERE id = %d AND parentEventID > 0";
    $count = $wpdb->get_var($wpdb->prepare($sql, $rsvpId));
    if ($count > 0) {
        return true;
    } else {
        return false;
    }
}

function rsvp_pro_is_parent_event($rsvpId)
{
    global $wpdb;

    $sql = "SELECT COUNT(*) FROM ".PRO_EVENT_TABLE." WHERE parentEventID = %d OR (id = %d AND IFNULL(parentEventID, 0) = 0)";
    $count = $wpdb->get_var($wpdb->prepare($sql, $rsvpId, $rsvpId));

    if ($count > 0) {
        return true;
    } else {
        return false;
    }
}

function rsvp_pro_event_access_type($rsvpId)
{
    global $wpdb;
    $accessType = RSVP_PRO_OPEN_EVENT_ACCESS;

    $tmpAccessType = $wpdb->get_var($wpdb->prepare("SELECT event_access FROM ".PRO_EVENT_TABLE." WHERE id = %d", $rsvpId));
    if ($tmpAccessType == RSVP_PRO_PRIVATE_EVENT_ACCESS) {
        $accessType = RSVP_PRO_PRIVATE_EVENT_ACCESS;
    }

    return $accessType;
}

function does_user_have_access_to_event($rsvpId, $attendeeId)
{
    global $wpdb;
    $haveAccess = false;

    $accessType = rsvp_pro_event_access_type($rsvpId);
    if ($accessType == RSVP_PRO_OPEN_EVENT_ACCESS) {
        $haveAccess = true;
    } else {
        // Select access does the person have access?
        $uid = $wpdb->get_var($wpdb->prepare(
            "SELECT rsvpAttendeeID FROM ".PRO_EVENT_ATTENDEE_TABLE." WHERE rsvpAttendeeID = %d AND rsvpEventID = %d",
            $attendeeId,
            $rsvpId
        ));
        if ($uid > 0) {
            $haveAccess = true;
        }
    }

    return $haveAccess;
}

function rsvp_pro_get_event_name( $event_id ) {
    return rsvp_pro_get_event_information( $event_id, RSVP_PRO_INFO_EVENT_NAME );
}

/**
 * Gets the list of columns that should be displayed in the admin attendee list
 * 
 * @param  int    $event_id The event ID we want to get the columns for
 * @return array            The array of attendee list columns that should be displayed
 */
function rsvp_pro_get_attendee_list_columns( $event_id ) {
    $attendee_list_columns = rsvp_pro_get_event_information( $event_id, RSVP_PRO_INFO_ATTENDEE_LIST_COLUMNS );

    if( !is_array( $attendee_list_columns) || ( count( $attendee_list_columns ) == 0 ) ) {
        $attendee_list_columns = rsvp_pro_default_attendee_list_columns( $event_id );
    }

    return $attendee_list_columns;
}

function get_number_additional( $rsvp_id, $attendee = null ) {
	$num_guests = 3;
	if ( rsvp_pro_get_event_option( $rsvp_id, RSVP_PRO_NUM_ADDITIONAL_GUESTS ) != '' ) {
		$num_guests = rsvp_pro_get_event_option( $rsvp_id, RSVP_PRO_NUM_ADDITIONAL_GUESTS );
		if ( ! is_numeric( $num_guests ) || ( $num_guests < 0 ) ) {
			$num_guests = 3;
		}
	}

	if ( ( null !== $attendee ) && is_a( $attendee, 'Rsvp_Pro_Attendee' ) && ( $attendee->get_num_guests() >= 0 ) ) {
		$num_guests = $attendee->get_num_guests();
	} elseif ( ( $attendee != null ) && is_numeric( $attendee->numGuests ) && ( ( $attendee->numGuests ) >= 0 ) ) {
		$num_guests = $attendee->numGuests;
	}

	return $num_guests;
}

function rsvp_pro_is_allowed_status($tmpRsvp)
{
    $allowedStatuses = array('yes', 'no', 'noresponse', 'waitlist', 'maybe', 'plusone');

    if (in_array(strtolower($tmpRsvp), $allowedStatuses)) {
        return true;
    }

    return false;
}

function rsvp_is_addslashes_enabled()
{
    return get_magic_quotes_gpc();
}

function rsvp_pro_is_network_activated()
{

  // Makes sure the plugin is defined before trying to use it
    if (! function_exists('is_plugin_active_for_network')) {
        require_once(ABSPATH . '/wp-admin/includes/plugin.php');
    }
    return is_plugin_active_for_network("rsvp-pro-plugin/rsvp-pro.php");
}

function rsvp_pro_admin_user_has_access_to_settings($rsvpId)
{
    global $current_user;

    // This is a hack but since this gets used in an environment where it
    // could be checking multiple events at the same time and by default rsvp_pro_get_event_option assumes
    // in the current context to only be looking at one main event
    $roles = rsvp_pro_get_sub_event_option($rsvpId, RSVP_PRO_OPTION_ADMIN_ROLES);
    if (current_user_can('manage_options')) {
        return true;
    }

    if (empty($roles) || (count($roles) <= 0)) {
        return true;
    } else {
        foreach ($roles as $role) {
            if (in_array(strtolower($role), $current_user->roles)) {
                return true;
            }
        }

        return false;
    }

    return false;
}

/**
 * Handles converting text encodings for characters like umlauts that might be stored in different encodings
 *
 * @param  string $text The text we wish to handle the encoding against
 * @return string       The converted text
 */
function rsvp_pro_handle_text_encoding($text)
{
    if (function_exists('mb_convert_encoding') && function_exists('mb_detect_encoding')) {
        return mb_convert_encoding($text, 'UTF-8', mb_detect_encoding($text, 'UTF-8, ISO-8859-1', true));
    }

    return $text;
}

function rsvp_pro_handle_attendee_check_in($rsvp_id, $attendee_id, $check_in_value)
{
    global $wpdb;

    if (rsvp_pro_is_sub_event($rsvp_id) || (
            rsvp_pro_is_shared_attendee_list_enabled() && ( $rsvp_id != RSVP_PRO_GLOBAL_ATTENDEE_EVENT_ID )
            && rsvp_pro_is_attendee_a_global_attendee( $attendee_id )
        )) {
        $sql = "SELECT id FROM " . PRO_ATTENDEE_SUB_EVENTS_TABLE . " WHERE rsvpAttendeeID = %d AND rsvpEventID = %d";
        $row_id = $wpdb->get_var($wpdb->prepare($sql, $attendee_id, $rsvp_id));
        if ($row_id) {
            $wpdb->update(
                PRO_ATTENDEE_SUB_EVENTS_TABLE,
                array(
                    "checked_in" => $check_in_value,
                ),
                array( "id" => $row_id ),
                array( '%s' ),
                array( '%d' )
            );
        } else {
            // Need to insert...
            $wpdb->insert(
                PRO_ATTENDEE_SUB_EVENTS_TABLE,
                array(
                    "checked_in" => $check_in_value,
                    "rsvpEventID" => $rsvp_id,
                    "rsvpAttendeeID" => $attendee_id,
                ),
                array( '%s', '%d', '%d' )
            );
        }
    } else {
        $wpdb->update(
            PRO_ATTENDEES_TABLE,
            array(
                "checked_in" => $check_in_value,
            ),
            array( "id" => $attendee_id ),
            array( '%s' ),
            array( '%d' )
        );
    }
}

/**
 * Gets the first page's permalink that the shortcode appears on.
 * @param  int    $rsvp_id The ID for the event we are trying to get the permalink for.
 * @return string          The URL or an empty string if nothing is found.
 */
function rsvp_pro_get_event_permalink($rsvp_id)
{
    $query_string = array(
        "s" => '[rsvppro id="' . $rsvp_id . '"]',
        "sentence" => 1
    );

    $query = new WP_Query($query_string);
    $event_url = "";
    if ($query->have_posts()) {
        $query->the_post();
        $event_url = get_permalink();
    }
    wp_reset_postdata();

    return $event_url;
}

/**
 * This function checks to see if the custom question exists
 * for a given event. This is used for operations like importing when
 * a user is trying to import data in with random IDs.
 *
 * @param  int $question_id The custom question ID
 * @param  int $event_id    The event ID
 * @return boolean          If the custom question exists for the event
 */
function rsvp_pro_custom_question_exists( $question_id, $event_id ) {
    global $wpdb;

    $cq_id = $wpdb->get_var( $wpdb->prepare( "SELECT id FROM " . PRO_QUESTIONS_TABLE . " WHERE id = %d AND rsvpEventID = %d", $question_id, $event_id ) );
    if ( ( $cq_id != null ) && ( $cq_id == $question_id ) ) {
        return true;
    }

    return false;
}

function rsvp_pro_get_parent_event_id( $event_id ) {
    global $wpdb;

    $sql = "SELECT parentEventID FROM " . PRO_EVENT_TABLE . " WHERE id = %d";

    return $wpdb->get_var( $wpdb->prepare( $sql, $event_id ) );
}

/**
 * Gets the RSVP counts for all the status types for a given event.
 *
 * @param  int $event_id The event ID we want to get the status types for
 * @return array         An associated array of RSVP statuses
 */
function rsvp_pro_get_rsvp_counts( $event_id )
{
    global $wpdb;

    if ( rsvp_pro_is_sub_event( $event_id ) ) {
        $baseSql = "SELECT COUNT(*)
                FROM ".PRO_ATTENDEES_TABLE." a
                LEFT JOIN ".PRO_ATTENDEE_SUB_EVENTS_TABLE." se ON se.rsvpAttendeeID = a.id AND se.rsvpEventID = %d
                LEFT JOIN ".PRO_EVENT_TABLE." e ON e.id = se.rsvpEventID
                WHERE ((IFNULL(e.event_access, '".RSVP_PRO_OPEN_EVENT_ACCESS."') != '".RSVP_PRO_PRIVATE_EVENT_ACCESS."') OR (a.id IN (SELECT rsvpAttendeeID FROM ".PRO_EVENT_ATTENDEE_TABLE." WHERE rsvpEventID = e.id))) AND ";

        $rsvp_event_where = " ( ( a.rsvpEventID = %d ) ";
        if( rsvp_pro_is_shared_attendee_list_enabled() ) {
            $rsvp_event_where .= " OR ( a.rsvpEventID = " . RSVP_PRO_GLOBAL_ATTENDEE_EVENT_ID . ") ";
        }
        $rsvp_event_where .= ")";

        $sub_event_id = $event_id;
        $parent_event_id = rsvp_pro_get_parent_event_id( $event_id );

        $yes_count = $wpdb->get_var( $wpdb->prepare( $baseSql." (se.rsvpStatus = 'Yes' OR se.rsvpStatus = 'PlusOne') AND " . $rsvp_event_where, $sub_event_id, $parent_event_id ) );

        $plus_one_count = $wpdb->get_var( $wpdb->prepare( $baseSql." se.rsvpStatus = 'PlusOne' AND " . $rsvp_event_where, $sub_event_id, $parent_event_id ) ); 

        $no_count = $wpdb->get_var( $wpdb->prepare( $baseSql . " se.rsvpStatus = 'No' AND " . $rsvp_event_where, $sub_event_id, $parent_event_id ) );

        $sql = $baseSql." (se.rsvpStatus = 'NoResponse' OR se.rsvpStatus IS NULL) AND " . $rsvp_event_where;
        if (rsvp_pro_get_event_information($sub_event_id, RSVP_PRO_INFO_EVENT_ACCESS) == RSVP_PRO_PRIVATE_EVENT_ACCESS) {
            $sql = "SELECT COUNT(*) FROM ".PRO_EVENT_ATTENDEE_TABLE." ea
                LEFT JOIN ".PRO_ATTENDEE_SUB_EVENTS_TABLE." se ON se.rsvpAttendeeID = ea.rsvpAttendeeID
                JOIN ".PRO_ATTENDEES_TABLE." a ON a.id = ea.rsvpAttendeeID
                WHERE (se.rsvpStatus IS NULL OR se.rsvpStatus = 'NoResponse') AND
                ea.rsvpEventID = %d AND " . $rsvp_event_where;
        }

        $no_response_count = $wpdb->get_var( $wpdb->prepare( $sql, $sub_event_id, $parent_event_id ) );
        $wait_list_count = $wpdb->get_var( $wpdb->prepare( $baseSql . " se.rsvpStatus = 'Waitlist' AND " . $rsvp_event_where, $sub_event_id, $parent_event_id ) );

        $maybe_count = $wpdb->get_var( $wpdb->prepare( $baseSql . " se.rsvpStatus = 'Maybe' AND " . $rsvp_event_where, $sub_event_id, $parent_event_id ) );
    } else {
        $baseSql = "SELECT COUNT(*) FROM ".PRO_ATTENDEES_TABLE." a
                JOIN ".PRO_EVENT_TABLE." e ON e.id = a.rsvpEventID
                WHERE ((IFNULL(e.event_access, '".RSVP_PRO_OPEN_EVENT_ACCESS."') != '".RSVP_PRO_PRIVATE_EVENT_ACCESS."') OR (a.id IN (SELECT rsvpAttendeeID FROM ".PRO_EVENT_ATTENDEE_TABLE." WHERE rsvpEventID = e.id))) ";

        $yes_count = $wpdb->get_var($wpdb->prepare($baseSql." AND (rsvpStatus = 'Yes' OR rsvpStatus = 'PlusOne') AND rsvpEventID = %d", $event_id));
        $plus_one_count = $wpdb->get_var($wpdb->prepare($baseSql." AND rsvpStatus = 'PlusOne' AND rsvpEventID = %d", $event_id));
        $no_count = $wpdb->get_var($wpdb->prepare($baseSql." AND rsvpStatus = 'No' AND rsvpEventID = %d", $event_id));
        $no_response_count = $wpdb->get_var($wpdb->prepare($baseSql." AND rsvpStatus = 'NoResponse' AND rsvpEventID = %d", $event_id));
        $wait_list_count = $wpdb->get_var($wpdb->prepare($baseSql." AND rsvpStatus = 'Waitlist' AND rsvpEventID = %d", $event_id));
        $maybe_count = $wpdb->get_var($wpdb->prepare($baseSql." AND rsvpStatus = 'Maybe' AND rsvpEventID = %d", $event_id));

        if( rsvp_pro_is_shared_attendee_list_enabled() ) {
            $baseSql = "SELECT COUNT(*) FROM " . PRO_ATTENDEES_TABLE . " a
                LEFT JOIN " . PRO_ATTENDEE_SUB_EVENTS_TABLE .  " se ON se.rsvpAttendeeID = a.id AND se.rsvpEventID = %d
                LEFT JOIN ".PRO_EVENT_TABLE." e ON e.id = se.rsvpEventID
                WHERE ((IFNULL(e.event_access, '".RSVP_PRO_OPEN_EVENT_ACCESS."') != '".RSVP_PRO_PRIVATE_EVENT_ACCESS."') OR (a.id IN (SELECT rsvpAttendeeID FROM ".PRO_EVENT_ATTENDEE_TABLE." WHERE rsvpEventID = e.id))) AND ";

            $sql = $baseSql." (se.rsvpStatus = 'Yes' or se.rsvpStatus = 'PlusOne')";
            $yes_count += $wpdb->get_var($wpdb->prepare($sql, $event_id));

            $sql = $baseSql." se.rsvpStatus = 'PlusOne' ";
            $plus_one_count += $wpdb->get_var($wpdb->prepare($sql, $event_id));

            $sql = $baseSql." se.rsvpStatus = 'No'";
            $no_count += $wpdb->get_var($wpdb->prepare($sql, $event_id));

            $sql = $baseSql." (((a.rsvpStatus = 'NoResponse' OR a.rsvpStatus IS NULL) AND a.rsvpEventID = %d) OR ( (se.rsvpStatus = 'NoResponse' OR se.rsvpStatus IS NULL) AND a.rsvpEventID = ". RSVP_PRO_GLOBAL_ATTENDEE_EVENT_ID ." ) ) ";
            $no_response_count = $wpdb->get_var($wpdb->prepare($sql, $event_id, $event_id));

            $sql = $baseSql." se.rsvpStatus = 'Waitlist'";
            $wait_list_count += $wpdb->get_var($wpdb->prepare($sql, $event_id));

            $sql = $baseSql." se.rsvpStatus = 'Maybe'";
            $maybe_count += $wpdb->get_var($wpdb->prepare($sql, $event_id));
        }
    }

    $results = array(
        'yes' => $yes_count,
        'no' => $no_count,
        'no_response' => $no_response_count,
        'wait_list' => $wait_list_count,
        'maybe' => $maybe_count,
        'plus_one' => $plus_one_count
    );

    return $results;
}

/**
 * Gets a string for the admin-end area of the RSVP plugin. If the
 * string key is found it or a translated string will be returned.
 *
 * @param  string $string_key Name of key that is associated with the string
 * @return string             The string that should be returned
 */
function rsvp_pro_get_admin_string( $string_key ) {
    global $admin_strings;
    global $us_admin_strings;

    if( $admin_strings == null ) {
        $admin_strings = rsvp_pro_get_admin_strings();
    }

    $string = "";

    if ( key_exists( $string_key, $admin_strings ) ) {
        // Set locale to english so we can get the original string to try and see if a
        // translation has been set by PolyLang. If not then revert and return original string.
        $new_string = $us_admin_strings[$string_key]['text'];
        $string = rsvp_pro_get_translated_string( $new_string );
        if( $string == $new_string )
        {
            $string = $admin_strings[$string_key]['text'];
        }
    }

    return $string;
}

/**
 * Gets a string for the front-end area of the RSVP plugin. If the
 * string key is found it or a translated string will be returned.
 *
 * @param  string $string_key Name of key that is associated with the string.
 * @return string             The string that should be returned.
 */
function rsvp_pro_get_frontend_string( $string_key ) {
	global $rsvp_pro_frontend_strings;
	global $us_rsvp_pro_frontend_strings;
	$string = '';
	if ( null === $rsvp_pro_frontend_strings ) {
		$rsvp_pro_frontend_strings = rsvp_pro_get_frontend_strings();
	}

	if ( key_exists( $string_key, $rsvp_pro_frontend_strings ) ) {
		$new_string = $us_rsvp_pro_frontend_strings[ $string_key ]['text'];
		$string     = rsvp_pro_get_translated_string( $new_string );
		if ( $string === $new_string ) {
			$string = $rsvp_pro_frontend_strings[ $string_key ]['text'];
		}
	}

	return $string;
}

/**
 * Gets the translated string. Does checks to see if the translation functions exist if
 * not then no translation occurs. We don't need to worry when it is WPML as they
 * have automagic voodoo which doesn't require us to retrieve it.
 *
 * @param  string $string The string we want translated
 * @return string         Either the original string or the translated string.
 */
function rsvp_pro_get_translated_string( $string ) {
	$text = $string;
	if( function_exists( 'pll__' ) ) {
    	$text = pll__( $string );
	}

	return $text;
}

/**
 * Tries to get a translated string for a dynamic property like custom
 * questions for a given event.
 *
 * @param  string $key_name The translation key name we are trying to retrieve.
 * @param  string $string   The current string we are trying to retrieve a translation for.
 * @param  int    $event_id The current event ID.
 * @return string           The translated text or the original text if no translation exists.
 */
function rsvp_pro_get_dynamic_translated_string( $key_name, $string, $event_id ) {
	$text = $string;

	if ( function_exists( 'pll__' ) ) {
		$text = pll__( $string );
	}

	if ( has_filter( 'wpml_translate_string' ) ) {
		$event_name = rsvp_pro_get_event_name( $event_id );
		$package    = array(
			'kind'  => "RSVPPro - {$event_id}",
			'name'  => "rsvp-pro-plugin-{$event_id}",
			'title' => "RSVP Pro Plugin - {$event_name}",
		);
		$key_name   = strtolower( $key_name );
		$key_name   = str_replace( ' ', '-', $key_name );
		$text       = apply_filters( 'wpml_translate_string', $string, $key_name, $package );
	}

	return $text;
}

/**
 * Checks to see if the global attendee list is enabled or not
 *
 * @return boolean True if the attendee list is enabled, false otherwise
 */
function rsvp_pro_is_shared_attendee_list_enabled() {
	return ( get_option( RSVP_PRO_GLOBAL_ENABLE_GLOBAL_ATTENDEE_LIST ) === 'Y' ) ? true : false;
}

/**
 * Checks to see if the change log functionality is turned on.
 *
 * @return boolean True if the change log is enabled, false otherwise.
 */
function rsvp_pro_is_change_log_enabled() {
	return ( 'Y' === get_option( RSVP_PRO_GLOBAL_OPTION_ENABLE_ATTENDEE_CHANGELOG ) ) ? true : false;
}

/**
 * This function checks to see if the user is part of the shared attendee list.
 *
 * @param  int   $attendee_id The attendee ID we want to check to see if it is part of the shared attendee list
 * @return bool               True if it is part of the shared attendee list, false otherwise
 */
function rsvp_pro_is_attendee_a_global_attendee( $attendee_id ) {
	global $wpdb;

	$sql = "SELECT id FROM " . PRO_ATTENDEES_TABLE . " WHERE id = %d AND rsvpEventID = %d";
	$tmp_id = $wpdb->get_var( $wpdb->prepare( $sql, $attendee_id, RSVP_PRO_GLOBAL_ATTENDEE_EVENT_ID ) );

	return ($tmp_id != null ) ? true : false;
}

/**
 * Returns the default columns that should be shown on the attendee list admin area
 * @param  int    $event_id The event ID we are getting the default columns for
 * @return array            The array of default columns for the event
 */
function rsvp_pro_default_attendee_list_columns( $event_id ) {
	global $wpdb;

	$columns = array(
		'attendee_name',
		'rsvp_status',
		'rsvp_date',
		'additional_attendee',
		'note',
		'associated_attendees',
	);

	$sql = "SELECT id FROM " . PRO_QUESTIONS_TABLE . " WHERE rsvpEventID = %d";
	$questions = $wpdb->get_results( $wpdb->prepare( $sql, $event_id ) );
	foreach ( $questions as $q ) {
		$columns[] = 'custom_question_' . $q->id;
	}

	return $columns;
}

/**
 * Replace a smart quote with an actual single-quote so that people can
 * find themselves when they do a search on the front-end.
 *
 * @param  string $in The string we want to replace smart-quotes with single-quotes.
 * @return string     The string that has had the values replaced.
 */
function rsvp_pro_smart_quote_replace( $in ) {
	return str_replace( '’', '\'', $in );
}

/**
 * Validates the submitted captcha to make sure a person has been "verified."
 *
 * @param  string $code_supplied The captcha code to check.
 * @return boolean               True if the captcha passes validation, false otherwise.
 */
function rsvp_pro_validate_recaptcha( $code_supplied ) {
	global $rsvp_id;

	$valid = false;

	$response = wp_remote_post(
		'https://www.google.com/recaptcha/api/siteverify',
		array(
			'method'   => 'POST',
			'blocking' => true,
			'body'     => array(
				'secret'   => rsvp_pro_get_event_option( $rsvp_id, RSVP_PRO_OPTION_RECAPTCHA_SECRET_KEY ),
				'response' => $code_supplied,
			),
		)
	);

	if ( ! is_wp_error( $response ) ) {
		$google_response = json_decode( wp_remote_retrieve_body( $response ) );
		if ( true === $google_response->success ) {
			$valid = true;
		}
	}
	return $valid;
}

/**
 * Generates the token used for attendees for auto-checking in an attendee via QR code.
 *
 * @return string The token used for checking in attendees.
 */
function rsvp_pro_generate_attendee_token() {
	return uniqid( '', true );
}

/**
 * Generates a QR code for attendee check-ins.
 *
 * @param  string $attendee_token The attendee token that should be used checking in.
 * @return string                 The path for the file we wish to attach.
 */
function rsvp_pro_generate_qr_for_email( $attendee_token ) {
	$url       = site_url( '/' );
	$url       = add_query_arg( 'rsvp_pro_attendee', $attendee_token, $url );
	$file_path = sys_get_temp_dir() . DIRECTORY_SEPARATOR . 'qr_code_' . uniqid() . '.png';

	QRcode::png( $url, $file_path );

	return $file_path;
}

/**
 * Encodes an image as base64 for including inline.
 *
 * @param  string $file_path The file path we want to encode.
 * @return string            The base64 encoded file contents OR false.
 */
function rsvp_pro_encode_image_as_base64( $file_path ) {
	if ( file_exists( $file_path ) ) {
		$type   = pathinfo( $file_path, PATHINFO_EXTENSION );
		$data   = file_get_contents( $file_path );
		$base64 = 'data:image/' . $type . ';base64,' . base64_encode( $data );

		return $base64;
	}

	return false;
}

/**
 * RSVP Pro wrapper for sending email. This is used to allow for
 * inline attachments, etc...
 *
 * @param string $email The email address we want to send the email to.
 * @param string $subject The subject for the email.
 * @param string $body The body of the email.
 * @param array  $headers The headers for the email.
 * @param array  $attachments The attachments for the email.
 */
function rsvp_pro_send_mail( $email, $subject, $body, $headers = '', $attachments = array() ) {
	global $rsvp_pro_inline_attachments;

	add_action( 'phpmailer_init', function( &$phpmailer ) use( $rsvp_pro_inline_attachments ) {
		$phpmailer->SMTPKeepAlive=true;
		if ( is_array( $rsvp_pro_inline_attachments ) && ( 0 < count( $rsvp_pro_inline_attachments ) ) ) {
			foreach ( $rsvp_pro_inline_attachments as $a ) {
				$phpmailer->AddEmbeddedImage( $a['file'], $a['uid'], $a['name'] );
			}
		}
	});
	wp_mail( $email, $subject, $body, $headers, $attachments );

	if ( is_array( $rsvp_pro_inline_attachments ) && ( 0 < count( $rsvp_pro_inline_attachments ) ) ) { 
		foreach ( $rsvp_pro_inline_attachments as $a ) {
			if ( file_exists( $a['name'] ) ) {
				unlink( $a['name'] );
			}
		}
	}
	$rsvp_pro_inline_attachments = array();
}
